[CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout: - c2h/ (27 files): Catch2 test helpers — generators, validators, runner - nvbench_helper/ (10 files): Benchmark harness utilities - cmake/ (29 files): CMake presets and build helpers - cudax/ (794 files): Experimental CUDA extensions - AGENTS.md: NVIDIA's official AI agent instructions for CCCL - CMakePresets.json: Standardized build configurations - cccl-version.json: Version tracking Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to competition value and PRD items. cccl_upstream now covers 100% of competition-critical assets: - 27 tuning headers (SM80/90/100 benchmark data) - 32 dispatch headers (algorithm implementations) - 60 Thrust examples (correctness verification) - 217 CUB Catch2 tests (regression matrix) - 153 CUB benchmarks (parameter space search) - 18 CUB examples (API verification) - 27 test helpers + benchmark harness - 794 cudax experimental extensions
This commit is contained in:
86
cccl_upstream/cudax/test/stf/graph/concurrency_test.cu
Normal file
86
cccl_upstream/cudax/test/stf/graph/concurrency_test.cu
Normal file
@@ -0,0 +1,86 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
|
||||
|
||||
#include <iostream>
|
||||
|
||||
/*
|
||||
* The goal of this test is to ensure that using read access modes actually
|
||||
* results in concurrent tasks
|
||||
*/
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
static __global__ void cuda_sleep_kernel(long long int clock_cnt)
|
||||
{
|
||||
long long int start_clock = clock64();
|
||||
long long int clock_offset = 0;
|
||||
while (clock_offset < clock_cnt)
|
||||
{
|
||||
clock_offset = clock64() - start_clock;
|
||||
}
|
||||
}
|
||||
|
||||
int main(int argc, char** argv)
|
||||
{
|
||||
int NTASKS = 256;
|
||||
int ms = 40;
|
||||
|
||||
if (argc > 1)
|
||||
{
|
||||
NTASKS = atoi(argv[1]);
|
||||
}
|
||||
|
||||
if (argc > 2)
|
||||
{
|
||||
ms = atoi(argv[2]);
|
||||
}
|
||||
|
||||
// cudaDevAttrClockRate: Peak clock frequency in kilohertz;
|
||||
int clock_rate;
|
||||
cuda_safe_call(cudaDeviceGetAttribute(&clock_rate, cudaDevAttrClockRate, 0));
|
||||
long long int clock_cnt = (long long int) (ms * clock_rate);
|
||||
|
||||
graph_ctx ctx;
|
||||
|
||||
int dummy[1];
|
||||
auto handle = ctx.logical_data(dummy);
|
||||
|
||||
ctx.task(handle.rw())->*[](cudaGraph_t graph, auto /*unused*/) {
|
||||
cudaGraphNode_t n;
|
||||
cuda_safe_call(cudaGraphAddEmptyNode(&n, graph, nullptr, 0));
|
||||
};
|
||||
|
||||
for (int iter = 0; iter < 10; iter++)
|
||||
{
|
||||
for (int k = 0; k < NTASKS; k++)
|
||||
{
|
||||
ctx.task(handle.read())->*[&](cudaStream_t stream, auto /*unused*/) {
|
||||
cuda_sleep_kernel<<<1, 1, 0, stream>>>(clock_cnt);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.task(handle.rw())->*[&](cudaGraph_t graph, auto /*unused*/) {
|
||||
cudaGraphNode_t n;
|
||||
cuda_safe_call(cudaGraphAddEmptyNode(&n, graph, nullptr, 0));
|
||||
};
|
||||
}
|
||||
|
||||
ctx.submit();
|
||||
|
||||
if (argc > 3)
|
||||
{
|
||||
std::cout << "Generating DOT output in " << argv[3] << '\n';
|
||||
ctx.print_to_dot(argv[3]);
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
Reference in New Issue
Block a user